import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';
//D3 se base sur canvas => render car rendu en svg
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => { //expliquer
  const title = 'US Auto Sales from 2005 to 2022';
  
  const xValue = d => d.Units; //display dates sur x axis
  const xAxisLabel = 'Units';

  const yValue = d => d.Item;
  const yAxisLabel = 'Item';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };//mm manière que CSS
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  //container
  
  const xScale = scaleTime()
  //complete set of values
    .domain(extent(data, xValue)) //returns the minimum and maximum value in an array from the given array using natural order.
    .range([0, innerWidth]) //output bounds
    .nice(); //round values out
  
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);//center g in svg
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(20);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d))); //coordinates in pixels
  
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
    console.log(lineGenerator(data))
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};

csv('https://gist.githubusercontent.com/Vaishnavi6199/aae09f4c4ad983d89bceaacb9ae95f2f/raw/6b5ecb4ffe8b5fa43298f38445732943c97f78d2/Book14.csv')
  .then(data => {
  	//console.log(data)
    data.forEach(d => {
    	d.Item = +d.Item;
      d.Units = new Date(d.Units)
    });
  console.log(data)
    render(data);
  })